Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(326)

Unified Diff: ports/devenv/install-base-packages.sh

Issue 1788953002: Do a check for nacl being enabled in devenv glibc. (Closed) Base URL: https://chromium.googlesource.com/webports.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ports/devenv/install-base-packages.sh
diff --git a/ports/devenv/install-base-packages.sh b/ports/devenv/install-base-packages.sh
index a2a2b08b5763b8332d1356b6640317bdb72e8648..743fce64fa2869a6b291075e539c7bcc8a627278 100755
--- a/ports/devenv/install-base-packages.sh
+++ b/ports/devenv/install-base-packages.sh
@@ -10,8 +10,8 @@
set -e
CheckNaClEnabled() {
- # Skip check on if this isn't newlib.
- if [[ ${TOOLCHAIN} != newlib ]]; then
+ # Skip check on if this isn't newlib or glibc.
+ if [[ ${TOOLCHAIN} != newlib && ${TOOLCHAIN} != glibc ]]; then
return
fi
TMP_CHECK_FILE="/tmp/.enable_nacl_check.nexe"
@@ -30,7 +30,7 @@ CheckNaClEnabled() {
echo " chrome://flags"
echo "You must then restart your browser."
echo
- echo "Eventually this should not be required."
+ echo "Eventually this may not be required."
echo "Follow this issue: https://crbug.com/477808"
echo
echo "*********************** ERROR ***********************"
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698